Learn R Programming

thinkr (version 0.15)

excel_to_ncol: return excel column position number from a column name

Description

return excel column position number from a column name

Usage

excel_to_ncol(col_name)

Arguments

col_name

the culum name

Examples

Run this code
excel_to_ncol("BF")

Run the code above in your browser using DataLab